@@ -25,25 +25,23 @@ HANDLERS = ["DeliciousHandler"]
 
 class DeliciousAction(ShowUrlAction):
     
-    def __init__(self, name, url, tags):
+    def __init__(self, name, url, tags=None):
+        """
+        @param tags: Is ignored since 2.23.1,
+        just there for backwards compatibility 
+        """
         ShowUrlAction.__init__(self, name, url)
-        self.tags = tags
         
     def get_verb(self):
-        return "<b>%(name)s</b>\n<span size='small' foreground='grey'>%(tags)s</span>"
-    
-    def get_name(self, text=None):
-        return {
-            "name": self._name,
-            "tags": ' '.join(self.tags),
-        }
+        return "<b>%(name)s</b>"
         
 class DeliciousMatch(deskbar.interfaces.Match):
     def __init__(self, url=None, tags=None, author=None, **args):
         deskbar.interfaces.Match.__init__ (self, icon="delicious.png", **args)
         self.url = url
         self.author = author
-        self.add_action( DeliciousAction(self.get_name(), self.url, tags) )
+        self.set_snippet(' '.join(tags))
+        self.add_action( DeliciousAction(self.get_name(), self.url) )
 
     def get_hash(self):
         return self.url
@@ -58,6 +56,7 @@ class DeliciousHandler(deskbar.interfaces.Module):
     
     def __init__(self):
         deskbar.interfaces.Module.__init__ (self)
+        self._delicious = DeliciousTagQueryEngine(self)
         self._bad_chars_pattern = re.compile("\s")
 
     def query(self, tag):
@@ -65,7 +64,7 @@ class DeliciousHandler(deskbar.interfaces.Module):
         tag = self._bad_chars_pattern.sub(' ', tag)
         
         #The queryyyyYyyYy :)
-        LOGGER.info( "Asking del.icio.us tags for %s" % tag )
+        LOGGER.info( "Asking del.icio.us tags for %s", tag )
         posts = self._delicious.get_posts_by_tag(tag)
 
         # TODO: Missing
@@ -139,6 +138,7 @@ class DeliciousTagQueryEngine:
         url = DEFAULT_QUERY_TAG % (urllib.quote_plus(self._user), urllib.quote_plus(tag))
         
         LOGGER.debug("Opening URL %s", url)
+        stream = None
         try:
             try:
                 stream = urllib.urlopen(url, proxies=deskbar.core.Utils.get_proxy())
@@ -148,7 +148,8 @@ class DeliciousTagQueryEngine:
             except ExpatError, e:
                 LOGGER.exception(e)
         finally:
-            stream.close()
+            if stream != None:
+                stream.close()
         
         #And return the results
         try:
